# Overviews

![PyPI](https://img.shields.io/pypi/v/pyexpansion) &nbsp;
![License: MIT](https://img.shields.io/github/license/weitaoyap111/pyexpansion)&nbsp;
![GitHub issues](https://img.shields.io/github/issues/weitaoyap111/pyexpansion)&nbsp;
![GitHub pull requests](https://img.shields.io/github/issues-pr/weitaoyap111/pyexpansion)&nbsp;
[![Downloads](https://static.pepy.tech/personalized-badge/pyexpansion?period=total&units=international_system&left_color=grey&right_color=brightgreen&left_text=Downloads)](https://pepy.tech/project/pyexpansion)&nbsp;

Python script that suddenly come to my idea <br>
Will update more...

# Installation
How to install:
```
pip install pyexpansion
```

# Library List:
## 1) PyIC
### What is this?
- Python Script that extract the ic information from ic word.

### How to use it?
- You can refer to PyIC\tests.py.

### Want knows more? 
you can read at PyIC\README.md

## 2) PyBrainFuck
### What is this?
- Python Script that decode and encode using BrainFuck.

### How to use it?
- You can refer to PyBrainFuck\tests.py.

### Want knows more? 
you can read at PyBrainFuck\README.md

# Projects Status
### Updated
- Apply for Malaysia Only
- Singapore Added
- PyBrainFuck is added

# Author
Copyright (c) 2023 Wei Tao Yap